@@ -88,24 +88,21 @@ class Config:
         self.color = color
         self.language = self.get_languages(language)
         transformers_config = self.convert_configure(transformers_config)
-        self.transformers = self.get_transformers_instances(
-            transformers, transformers_config, force_order, target_version, skip
-        )
-        transformer_map = {transformer.__class__.__name__: transformer for transformer in self.transformers}
-        for transformer in self.transformers:
-            # inject global settings TODO: handle it better
-            setattr(transformer, "formatting_config", self.formatting)
-            setattr(transformer, "transformers", transformer_map)
-            setattr(transformer, "languages", self.language)
+        self.transformers = []
+        self.transformers_lookup = dict()
+        self.load_transformers(transformers, transformers_config, force_order, target_version, skip)
 
-    @staticmethod
-    def get_transformers_instances(transformers, transformers_config, force_order, target_version, skip):
-        return [
-            transformer.instance
-            for transformer in load_transformers(
-                transformers, transformers_config, force_order=force_order, target_version=target_version, skip=skip
-            )
-        ]
+    def load_transformers(self, transformers, transformers_config, force_order, target_version, skip):
+        transformers = load_transformers(
+            transformers, transformers_config, force_order=force_order, target_version=target_version, skip=skip
+        )
+        for transformer in transformers:
+            # inject global settings TODO: handle it better
+            setattr(transformer.instance, "formatting_config", self.formatting)
+            setattr(transformer.instance, "transformers", self.transformers_lookup)
+            setattr(transformer.instance, "languages", self.language)
+            self.transformers.append(transformer.instance)
+            self.transformers_lookup[transformer.name] = transformer.instance
 
     @staticmethod
     def convert_configure(configure: List[Tuple[str, List]]) -> Dict[str, List]:
