@@ -1,6 +1,6 @@
 from collections import defaultdict
 
-from robot.api.parsing import ModelTransformer, Token
+from robot.api.parsing import Token
 from robot.parsing.model import Statement
 
 from robotidy.disablers import skip_section_if_disabled
@@ -42,8 +42,6 @@ class AlignVariablesSection(Transformer):
     ```
 
     To align all columns set ``up_to_column`` to 0.
-
-    Supports global formatting params: ``--startline`` and ``--endline``.
     """
 
     def __init__(self, up_to_column: int = 2, skip_types: str = "", min_width: int = None):
