@@ -1,10 +1,11 @@
-from robot.api.parsing import ModelTransformer, Token
+from robot.api.parsing import Token
 from robot.utils.normalizing import normalize_whitespace
 
 from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
+from robotidy.transformers import Transformer
 
 
-class NormalizeSettingName(ModelTransformer):
+class NormalizeSettingName(Transformer):
     """
     Normalize setting name.
     Ensure that setting names are title case without leading or trailing whitespace. For example from:
@@ -34,10 +35,11 @@ class NormalizeSettingName(ModelTransformer):
         [Arguments]    ${arg}
         [Documentation]   Setup Keyword
     ```
-
-    Supports global formatting params: ``--startline`` and ``--endline``.
     """
 
+    def __init__(self):
+        super().__init__()  # workaround for our dynamically imported classes with args from cli/config
+
     @skip_section_if_disabled
     def visit_Section(self, node):  # noqa
         return self.generic_visit(node)
